@@ -11,14 +11,15 @@ LOGGER = logging.getLogger(__name__)
 
 def create_must_gather_command(
     dest_dir,
-    image_url,
+    image_url=None,
     script_name=None,
     kubeconfig=None,
     skip_tls_check=False,
 ):
     base_command = (
         f"oc adm must-gather {f'--insecure-skip-tls-verify' if skip_tls_check else ''} "
-        f"{f'--kubeconfig {kubeconfig}' if kubeconfig else ''} --image={image_url} --dest-dir={dest_dir}"
+        f"{f'--kubeconfig {kubeconfig}' if kubeconfig else ''} {f'--image={image_url}' if image_url else ''} "
+        f"--dest-dir={dest_dir}"
     )
     return f"{base_command} -- {script_name}" if script_name else base_command
 
